$base-color: #59524c;

@use "../_admin.scss" with (
	$scheme-name: "coffee",
	$base-color: $base-color,
	$highlight-color: #c7a589,
	$notification-color: #9ea476,
	$form-checked: $base-color,

	$low-contrast-theme: "true"
);
